@@ -1,7 +1,5 @@
-import importlib
 import logging
 import os
-import pathlib
 from types import FunctionType
 from typing import List, Tuple
 
@@ -68,23 +66,10 @@ class ApplicationContext(object):
         self.repositories = set()
         self.repository_names = set()
         self.service_names = set()
-
-        root_dir = pathlib.Path(self.settings.ROOT_DIR)
-        for file_name in pathlib.Path(os.path.dirname(self.settings.BASE_DIR)).glob(
-            "service/**/*.py"
-        ):
-            parts = file_name.parts[len(root_dir.parts) :]
-            if parts[-1].startswith("_"):
-                parts = parts[:-1]
-            importlib.import_module(".".join(parts).replace(".py", ""))
-
         self.load_internal_services()
         self.load_repositories()
         self.load_egress_services()
-
-        from fractal.core.event_sourcing.event_publisher import EventPublisher
-
-        self.event_publisher = EventPublisher(self.load_event_projectors())
+        self.load_event_publisher()
         self.load_command_bus()
         self.load_ingress_services()
 
@@ -105,21 +90,13 @@ class ApplicationContext(object):
     def load_internal_services(self):
         """Load services for internal use of the domain."""
         for name, service in self.registered_internal_services:
-            self.install_service(
+            _service = self.install_service(
                 service(self.settings)
                 if isinstance(service, FunctionType)
                 else service,
                 name=name,
             )
-
-        if hasattr(self.settings, "SECRET_KEY") and self.settings.SECRET_KEY:
-            from fractal.contrib.tokens.services import AutomaticJwtTokenService
-
-            self.install_service(AutomaticJwtTokenService, name="token_service")
-        else:
-            from fractal.contrib.tokens.services import StaticTokenService
-
-            self.install_service(StaticTokenService, name="token_service")
+            setattr(self, name, _service())
 
     def load_repositories(self):
         """Load repositories for data access"""
@@ -185,12 +162,18 @@ class ApplicationContext(object):
     def load_egress_services(self):
         """Load services to external interfaces that are initiated by this service (outbound)"""
         for name, service in self.registered_egress_services:
-            self.install_service(
+            _service = self.install_service(
                 service(self.settings)
                 if isinstance(service, FunctionType)
                 else service,
                 name=name,
             )
+            setattr(self, name, _service())
+
+    def load_event_publisher(self):
+        from fractal.core.event_sourcing.event_publisher import EventPublisher
+
+        self.event_publisher = EventPublisher(self.load_event_projectors())
 
     def load_event_projectors(self):
         from fractal.core.event_sourcing.event import EventCommandMapper
@@ -201,12 +184,6 @@ class ApplicationContext(object):
 
         projectors = []
 
-        self.command_bus_projector = CommandBusProjector(
-            lambda: self.command_bus,
-            all_subclasses(EventCommandMapper),
-        )
-        projectors.append(self.command_bus_projector)
-
         if getattr(self.settings, "EVENT_STORE_PROJECTOR", None):
             from fractal.core.event_sourcing.projectors.event_store_projector import (
                 EventStoreProjector,
@@ -231,6 +208,13 @@ class ApplicationContext(object):
                 ),
             )
 
+        # First process all notifiers/emitters/persistency before chaining commands (and projecting new events)
+        self.command_bus_projector = CommandBusProjector(
+            lambda: self.command_bus,
+            all_subclasses(EventCommandMapper),
+        )
+        projectors.append(self.command_bus_projector)
+
         return projectors
 
     def load_command_bus(self):
@@ -244,12 +228,13 @@ class ApplicationContext(object):
     def load_ingress_services(self):
         """Load services to external interfaces that are initiated by the external services (inbound)"""
         for name, service in self.registered_ingress_services:
-            self.install_service(
+            _service = self.install_service(
                 service(self.settings)
                 if isinstance(service, FunctionType)
                 else service,
                 name=name,
             )
+            setattr(self, name, _service())
 
     def install_repository(self, repository, *, name=""):
         if not name:
@@ -266,16 +251,18 @@ class ApplicationContext(object):
 
             name = camel_to_snake(service.__name__)
         self.service_names.add(name)
-        setattr(
-            ApplicationContext, name, property(lambda self: next(service.install(self)))
-        )
+        _service = service.install(self)
+        setattr(ApplicationContext, name, lambda self: next(_service))
+        return lambda: next(_service)
 
     @property
     def services(self):
-        services = []
         for service_name in self.service_names:
-            services.append(getattr(self, service_name))
-        return services
+            service = getattr(self, service_name)
+            if callable(service):
+                service = service()
+                setattr(self, service_name, service)
+            yield service
 
     def get_parameters(self, parameters: List[str]) -> Tuple:
         for parameter in parameters:
